.. currentmodule:: sardana.sardanamodulemanager

:mod:`~sardana.pool.sardanamodulemanager`
==========================================

.. automodule:: sardana.sardanamodulemanager

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`ModuleManager`


ModuleManager
---------------

.. inheritance-diagram:: ModuleManager
    :parts: 1
    
.. autoclass:: ModuleManager
    :inherited-members:
    :members:
    :undoc-members:
